@@ -5,7 +5,8 @@ import pandas as pd
 import yaml
 from pymongo import MongoClient
 from termcolor2 import colored
-
+import os
+from dotenv import load_dotenv
 warnings.filterwarnings("ignore")
 
 
@@ -15,13 +16,14 @@ class MongoLoader:
         self.report_name = report_name
         self.bi_department = bi_departement
         self.date = date
-        if os.path.isdir(r'/Configs/Global/'):
-            self.conf_r = r'/Configs/Global/'
-        else:
-            self.conf_r = r'../Configs/Global/'
+        load_dotenv()
+        self.db_conf = os.getenv('DB_CONFIG')
+        kp_path = os.getenv('KEYPASS')
+        conf_r = os.getenv('ENTITY_CONFIGS')
+
 
     def writereport(self, report_data: pd.DataFrame):
-        with open(self.conf_r + 'db.yaml') as file:
+        with open(self.db_conf) as file:
             documents = yaml.full_load(file)
         mongodb_port = documents['database']['MongoDB']['port']
         mongodb_host = documents['database']['MongoDB']['host']
