@@ -5,11 +5,16 @@ from termcolor2 import colored
 from dwhutils.TableReader import read_raw_sql_hub as r_hub
 from dwhutils.TableReader import read_raw_sql_sat as r_sat
 from dwhutils.db_connection import connect_to_db
-
+import os
+from dotenv import load_dotenv
 
 class ReadEntity:
 
     def __init__(self, entity_name: str, p_date: str, exclude_sat_list: list = [], layer: str = None):
+        load_dotenv()
+        self.db_conf = os.getenv('DB_CONFIG')
+        self.kp_path = os.getenv('KEYPASS')
+        self.conf_r = os.getenv('ENTITY_CONFIGS')
         self.entity_name = entity_name.lower()
         self.p_date = p_date
         self.exclude_sat_list = exclude_sat_list
@@ -19,11 +24,9 @@ class ReadEntity:
         self.test_table_existance()
 
     def read_config(self):
-        if os.path.isdir(r'/Configs/ENB/'):
-            conf_r = r'/Configs/ENB/'
-        else:
-            conf_r = r'../Configs/ENB/'
-        with open(conf_r + self.entity_name + '.yaml') as file:
+        conf_r = self.conf_r
+
+        with open(os.path.join(conf_r,  self.entity_name + '.yaml')) as file:
             self.config = yaml.full_load(file)
 
     def test_table_existance(self):
