@@ -2,10 +2,15 @@ import pandas as pd
 from sqlalchemy import MetaData
 
 from dwhutils.db_connection import connect_to_db
+import os
+from dotenv import load_dotenv
+
+
+
 
 class dynamic_lkp:
     def __init__(self):
-        pass
+        load_dotenv()
 
 
     def build_lkp(self,column,tablename):
