@@ -1,19 +1,23 @@
 # package import
+import os
+
 import yaml
+from dotenv import load_dotenv
 from pykeepass import PyKeePass
 from sqlalchemy.engine import create_engine
 from sshtunnel import SSHTunnelForwarder
 
 
-def connect_to_db(layer: str = None, config_fp: str = '', keypass_fp: str = ''):
+def connect_to_db(layer: str = None):
     '''
     :param layer: database layer
     :param config_fp: filepath to db config
     :param keypass_fp: filepath to keypassfile
     :return: databse connection (mariadb)
     '''
-    config_file = config_fp
-    kp_path = keypass_fp
+    load_dotenv()
+    config_file = os.getenv('DB_CONFIG')
+    kp_path = os.getenv('KEYPASS')
 
     with open(config_file) as file:
         documents = yaml.full_load(file)
