@@ -56,12 +56,12 @@ class LoadtoDB():
 
 
         if entityName is None:
-            with open(conf_r + t_name + '.yaml') as file:
+            with open(os.path.join(conf_r , t_name + '.yaml')) as file:
                 self.documents = yaml.full_load(file)
             self.hk = self.documents[t_name]['hash_key']
             self.fields = self.documents[t_name]['fields']
         else:
-            with open(conf_r + self.entityName + '.yaml') as file:
+            with open(os.path.join(conf_r + self.entityName + '.yaml')) as file:
                 self.documents = yaml.full_load(file)
             self.hk = self.documents[entityName]['tables'][self.t_name]['hash_key']
             self.fields = self.documents[entityName]['tables'][self.t_name]['fields']
